@@ -3,7 +3,7 @@
 ##############################################################################
 ##
 ##  Canon Inkjet Printer Driver for Linux
-##  Copyright CANON INC. 2001-2017
+##  Copyright CANON INC. 2001-2019
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 ##
 ##############################################################################
 
-C_version="5.50-1"
-C_copyright_end="2017"
+C_version="5.80-1"
+C_copyright_end="2019"
 C_default_system="rpm"
 
-P_support_printer=("E200" "E300" "E3100" "TR7500" "TR7530" "TR8500" "TR8530" "TR8580" "TS200" "TS300" "TS3100" "TS5100" "TS6100" "TS6130" "TS6180" "TS8100" "TS8180" "TS9100" "TS9180" "TS8130" "XK70" "XK50")
+P_support_printer=("TR703" "TS708" "TS700")
 
 L_INST_COM_01_01="Command executed = %s\n"
 
