@@ -1,6 +1,6 @@
 /*
  *  Canon Inkjet Printer Driver for Linux
- *  Copyright CANON INC. 2014
+ *  Copyright CANON INC. 2001-2019
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -49,6 +49,8 @@ static const MapTbl mediatypeTbl[] = {
 	{ "label", CNCL_PSET_MEDIA_LABEL },
 	{ "highres", CNCL_PSET_MEDIA_HIGHRES },
 	{ "photo", CNCL_PSET_MEDIA_OTHER_PHOTO_PAPER },
+	{ "greetingcard", CNCL_PSET_MEDIA_GREETING_CARD },
+	{ "cardstock", CNCL_PSET_MEDIA_CARDSTOCK },
 	{ NULL, -1 },
 };
 
@@ -76,6 +78,8 @@ static const MapTbl papersizeTbl[] = {
 	{ "4x6.bl", CNCL_PSET_SIZE_4X6 },
 	{ "5x7", CNCL_PSET_SIZE_5X7 },
 	{ "5x7.bl", CNCL_PSET_SIZE_5X7 },
+	{ "7x10", CNCL_PSET_SIZE_7X10 },
+	{ "7x10.bl", CNCL_PSET_SIZE_7X10 },
 	{ "8x10", CNCL_PSET_SIZE_6GIRI },
 	{ "8x10.bl", CNCL_PSET_SIZE_6GIRI },
 	{ "10x12", CNCL_PSET_SIZE_4GIRI },
@@ -90,8 +94,14 @@ static const MapTbl papersizeTbl[] = {
 	{ "envelopdlp", CNCL_PSET_SIZE_ENV_DL },
 	{ "businesscard", CNCL_PSET_SIZE_BUSINESSCARD },
 	{ "businesscard.bl", CNCL_PSET_SIZE_BUSINESSCARD },
+	{ "square89", CNCL_PSET_SIZE_SQUARE_89 },
+	{ "square89.bl", CNCL_PSET_SIZE_SQUARE_89 },
+	{ "square4in", CNCL_PSET_SIZE_SQUARE_4IN },
+	{ "square4in.bl", CNCL_PSET_SIZE_SQUARE_4IN },
 	{ "square127", CNCL_PSET_SIZE_SQUARE_127 },
 	{ "square127.bl", CNCL_PSET_SIZE_SQUARE_127 },
+	{ "square12in", CNCL_PSET_SIZE_SQUARE_12IN },
+	{ "square12in.bl", CNCL_PSET_SIZE_SQUARE_12IN },
 	{ NULL, -1 },
 };
 
