@@ -1,6 +1,6 @@
 /*
  *  Canon Inkjet Printer Driver for Linux
- *  Copyright CANON INC. 2014
+ *  Copyright CANON INC. 2001-2019
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,6 +48,8 @@
 #define CNCL_PSET_MEDIA_LABEL (18)
 #define CNCL_PSET_MEDIA_HIGHRES (15)
 #define CNCL_PSET_MEDIA_OTHER_PHOTO_PAPER (16)
+#define CNCL_PSET_MEDIA_GREETING_CARD (25)
+#define CNCL_PSET_MEDIA_CARDSTOCK (26)
 
 /* pagesize */
 #define CNCL_PSET_SIZE_LETTER (1)
@@ -67,6 +69,7 @@
 #define CNCL_PSET_SIZE_LEGAL_INDIA (28)
 #define CNCL_PSET_SIZE_4X6 (9)
 #define CNCL_PSET_SIZE_5X7 (10)
+#define CNCL_PSET_SIZE_7X10 (78)
 #define CNCL_PSET_SIZE_6GIRI (11)
 #define CNCL_PSET_SIZE_4GIRI (12)
 #define CNCL_PSET_SIZE_L (14)
@@ -75,7 +78,10 @@
 #define CNCL_PSET_SIZE_ENV_10 (20)
 #define CNCL_PSET_SIZE_ENV_DL (21)
 #define CNCL_PSET_SIZE_BUSINESSCARD (18)
+#define CNCL_PSET_SIZE_SQUARE_89 (82)
+#define CNCL_PSET_SIZE_SQUARE_4IN (79)
 #define CNCL_PSET_SIZE_SQUARE_127 (29)
+#define CNCL_PSET_SIZE_SQUARE_12IN (80)
 
 /* colormode */
 #define CNCL_PSET_COLORMODE_MONO (2)
